from setuptools import setup
import os


def read(fname):
    with open(os.path.join(os.path.dirname(__file__), fname)) as fp:
        s = fp.read()
    return s


def get_version(path):
    with open(path, "r") as fp:
        lines = fp.read()
    for line in lines.split("\n"):
        if line.startswith('__version__'):
            delim = '"' if '"' in line else "'"
            return line.split(delim)[1]
    raise RuntimeError("Unable to find version string.")


setup(name='nlptasks',
      version=get_version("nlptasks/__init__.py"),
      description=(
          "Boilerplate code to wrap different libs for NLP tasks."
      ),
      # long_description=read('README.rst'),  # still not working
      url='http://github.com/ulf1/nlptasks',
      author='Ulf Hamster',
      author_email='554c46@gmail.com',
      license='Apache License 2.0',
      packages=['nlptasks'],
      install_requires=[
          'torch>=1.1.0,<2',
          'tensorflow>=2.4.0,<3',
          'numpy>=1.18.0,<2',
          'scipy>=1.5.0,<2',
          'pandas>=1.1.0,<2',
          'spacy==2.3.*',
          'spacy-lookups-data==0.3.*',
          'stanza==1.1.*',
          'flair==0.7.*',
          'nltk==3.5',
          'SoMaJo==2.1.1',
          'SoMeWeTa==1.7.1',
          'pad-sequences>=0.5.*',
          'treesimi>=0.1.1'
      ],
      scripts=[
          'scripts/nlptasks_downloader.py'
      ],
      python_requires='>=3.6',
      zip_safe=True)
